============
Installation
============

At the command line::

    $ pip install superraenn


For a development install of SuperRAENN, clone the repository and then install into your Python environment::

    $ git clone https://github.com/villrv/SuperRAENN
    $ cd SuperRAENN
    $ python setup.py develop